# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from opentelemetry.proto.common.v1.common_pb2 import (
    InstrumentationLibrary as opentelemetry___proto___common___v1___common_pb2___InstrumentationLibrary,
    StringKeyValue as opentelemetry___proto___common___v1___common_pb2___StringKeyValue,
)

from opentelemetry.proto.resource.v1.resource_pb2 import (
    Resource as opentelemetry___proto___resource___v1___resource_pb2___Resource,
)

from typing import (
    Iterable as typing___Iterable,
    List as typing___List,
    NewType as typing___NewType,
    Optional as typing___Optional,
    Text as typing___Text,
    Tuple as typing___Tuple,
    Union as typing___Union,
    cast as typing___cast,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
builtin___str = str
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

AggregationTemporalityValue = typing___NewType('AggregationTemporalityValue', builtin___int)
type___AggregationTemporalityValue = AggregationTemporalityValue
class AggregationTemporality(object):
    DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
    @classmethod
    def Name(cls, number: builtin___int) -> builtin___str: ...
    @classmethod
    def Value(cls, name: builtin___str) -> AggregationTemporalityValue: ...
    @classmethod
    def keys(cls) -> typing___List[builtin___str]: ...
    @classmethod
    def values(cls) -> typing___List[AggregationTemporalityValue]: ...
    @classmethod
    def items(cls) -> typing___List[typing___Tuple[builtin___str, AggregationTemporalityValue]]: ...
    AGGREGATION_TEMPORALITY_UNSPECIFIED = typing___cast(AggregationTemporalityValue, 0)
    AGGREGATION_TEMPORALITY_DELTA = typing___cast(AggregationTemporalityValue, 1)
    AGGREGATION_TEMPORALITY_CUMULATIVE = typing___cast(AggregationTemporalityValue, 2)
AGGREGATION_TEMPORALITY_UNSPECIFIED = typing___cast(AggregationTemporalityValue, 0)
AGGREGATION_TEMPORALITY_DELTA = typing___cast(AggregationTemporalityValue, 1)
AGGREGATION_TEMPORALITY_CUMULATIVE = typing___cast(AggregationTemporalityValue, 2)
type___AggregationTemporality = AggregationTemporality

class ResourceMetrics(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def resource(self) -> opentelemetry___proto___resource___v1___resource_pb2___Resource: ...

    @property
    def instrumentation_library_metrics(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___InstrumentationLibraryMetrics]: ...

    def __init__(self,
        *,
        resource : typing___Optional[opentelemetry___proto___resource___v1___resource_pb2___Resource] = None,
        instrumentation_library_metrics : typing___Optional[typing___Iterable[type___InstrumentationLibraryMetrics]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> ResourceMetrics: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> ResourceMetrics: ...
    def HasField(self, field_name: typing_extensions___Literal[u"resource",b"resource"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"instrumentation_library_metrics",b"instrumentation_library_metrics",u"resource",b"resource"]) -> None: ...
type___ResourceMetrics = ResourceMetrics

class InstrumentationLibraryMetrics(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def instrumentation_library(self) -> opentelemetry___proto___common___v1___common_pb2___InstrumentationLibrary: ...

    @property
    def metrics(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___Metric]: ...

    def __init__(self,
        *,
        instrumentation_library : typing___Optional[opentelemetry___proto___common___v1___common_pb2___InstrumentationLibrary] = None,
        metrics : typing___Optional[typing___Iterable[type___Metric]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> InstrumentationLibraryMetrics: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> InstrumentationLibraryMetrics: ...
    def HasField(self, field_name: typing_extensions___Literal[u"instrumentation_library",b"instrumentation_library"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"instrumentation_library",b"instrumentation_library",u"metrics",b"metrics"]) -> None: ...
type___InstrumentationLibraryMetrics = InstrumentationLibraryMetrics

class Metric(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    name: typing___Text = ...
    description: typing___Text = ...
    unit: typing___Text = ...

    @property
    def int_gauge(self) -> type___IntGauge: ...

    @property
    def double_gauge(self) -> type___DoubleGauge: ...

    @property
    def int_sum(self) -> type___IntSum: ...

    @property
    def double_sum(self) -> type___DoubleSum: ...

    @property
    def int_histogram(self) -> type___IntHistogram: ...

    @property
    def double_histogram(self) -> type___DoubleHistogram: ...

    def __init__(self,
        *,
        name : typing___Optional[typing___Text] = None,
        description : typing___Optional[typing___Text] = None,
        unit : typing___Optional[typing___Text] = None,
        int_gauge : typing___Optional[type___IntGauge] = None,
        double_gauge : typing___Optional[type___DoubleGauge] = None,
        int_sum : typing___Optional[type___IntSum] = None,
        double_sum : typing___Optional[type___DoubleSum] = None,
        int_histogram : typing___Optional[type___IntHistogram] = None,
        double_histogram : typing___Optional[type___DoubleHistogram] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> Metric: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Metric: ...
    def HasField(self, field_name: typing_extensions___Literal[u"data",b"data",u"double_gauge",b"double_gauge",u"double_histogram",b"double_histogram",u"double_sum",b"double_sum",u"int_gauge",b"int_gauge",u"int_histogram",b"int_histogram",u"int_sum",b"int_sum"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"data",b"data",u"description",b"description",u"double_gauge",b"double_gauge",u"double_histogram",b"double_histogram",u"double_sum",b"double_sum",u"int_gauge",b"int_gauge",u"int_histogram",b"int_histogram",u"int_sum",b"int_sum",u"name",b"name",u"unit",b"unit"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"data",b"data"]) -> typing_extensions___Literal["int_gauge","double_gauge","int_sum","double_sum","int_histogram","double_histogram"]: ...
type___Metric = Metric

class IntGauge(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def data_points(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___IntDataPoint]: ...

    def __init__(self,
        *,
        data_points : typing___Optional[typing___Iterable[type___IntDataPoint]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> IntGauge: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> IntGauge: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"data_points",b"data_points"]) -> None: ...
type___IntGauge = IntGauge

class DoubleGauge(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def data_points(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___DoubleDataPoint]: ...

    def __init__(self,
        *,
        data_points : typing___Optional[typing___Iterable[type___DoubleDataPoint]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> DoubleGauge: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> DoubleGauge: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"data_points",b"data_points"]) -> None: ...
type___DoubleGauge = DoubleGauge

class IntSum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    aggregation_temporality: type___AggregationTemporalityValue = ...
    is_monotonic: builtin___bool = ...

    @property
    def data_points(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___IntDataPoint]: ...

    def __init__(self,
        *,
        data_points : typing___Optional[typing___Iterable[type___IntDataPoint]] = None,
        aggregation_temporality : typing___Optional[type___AggregationTemporalityValue] = None,
        is_monotonic : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> IntSum: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> IntSum: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"aggregation_temporality",b"aggregation_temporality",u"data_points",b"data_points",u"is_monotonic",b"is_monotonic"]) -> None: ...
type___IntSum = IntSum

class DoubleSum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    aggregation_temporality: type___AggregationTemporalityValue = ...
    is_monotonic: builtin___bool = ...

    @property
    def data_points(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___DoubleDataPoint]: ...

    def __init__(self,
        *,
        data_points : typing___Optional[typing___Iterable[type___DoubleDataPoint]] = None,
        aggregation_temporality : typing___Optional[type___AggregationTemporalityValue] = None,
        is_monotonic : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> DoubleSum: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> DoubleSum: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"aggregation_temporality",b"aggregation_temporality",u"data_points",b"data_points",u"is_monotonic",b"is_monotonic"]) -> None: ...
type___DoubleSum = DoubleSum

class IntHistogram(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    aggregation_temporality: type___AggregationTemporalityValue = ...

    @property
    def data_points(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___IntHistogramDataPoint]: ...

    def __init__(self,
        *,
        data_points : typing___Optional[typing___Iterable[type___IntHistogramDataPoint]] = None,
        aggregation_temporality : typing___Optional[type___AggregationTemporalityValue] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> IntHistogram: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> IntHistogram: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"aggregation_temporality",b"aggregation_temporality",u"data_points",b"data_points"]) -> None: ...
type___IntHistogram = IntHistogram

class DoubleHistogram(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    aggregation_temporality: type___AggregationTemporalityValue = ...

    @property
    def data_points(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___DoubleHistogramDataPoint]: ...

    def __init__(self,
        *,
        data_points : typing___Optional[typing___Iterable[type___DoubleHistogramDataPoint]] = None,
        aggregation_temporality : typing___Optional[type___AggregationTemporalityValue] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> DoubleHistogram: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> DoubleHistogram: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"aggregation_temporality",b"aggregation_temporality",u"data_points",b"data_points"]) -> None: ...
type___DoubleHistogram = DoubleHistogram

class IntDataPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    start_time_unix_nano: builtin___int = ...
    time_unix_nano: builtin___int = ...
    value: builtin___int = ...

    @property
    def labels(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]: ...

    @property
    def exemplars(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___IntExemplar]: ...

    def __init__(self,
        *,
        labels : typing___Optional[typing___Iterable[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]] = None,
        start_time_unix_nano : typing___Optional[builtin___int] = None,
        time_unix_nano : typing___Optional[builtin___int] = None,
        value : typing___Optional[builtin___int] = None,
        exemplars : typing___Optional[typing___Iterable[type___IntExemplar]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> IntDataPoint: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> IntDataPoint: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"exemplars",b"exemplars",u"labels",b"labels",u"start_time_unix_nano",b"start_time_unix_nano",u"time_unix_nano",b"time_unix_nano",u"value",b"value"]) -> None: ...
type___IntDataPoint = IntDataPoint

class DoubleDataPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    start_time_unix_nano: builtin___int = ...
    time_unix_nano: builtin___int = ...
    value: builtin___float = ...

    @property
    def labels(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]: ...

    @property
    def exemplars(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___DoubleExemplar]: ...

    def __init__(self,
        *,
        labels : typing___Optional[typing___Iterable[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]] = None,
        start_time_unix_nano : typing___Optional[builtin___int] = None,
        time_unix_nano : typing___Optional[builtin___int] = None,
        value : typing___Optional[builtin___float] = None,
        exemplars : typing___Optional[typing___Iterable[type___DoubleExemplar]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> DoubleDataPoint: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> DoubleDataPoint: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"exemplars",b"exemplars",u"labels",b"labels",u"start_time_unix_nano",b"start_time_unix_nano",u"time_unix_nano",b"time_unix_nano",u"value",b"value"]) -> None: ...
type___DoubleDataPoint = DoubleDataPoint

class IntHistogramDataPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    start_time_unix_nano: builtin___int = ...
    time_unix_nano: builtin___int = ...
    count: builtin___int = ...
    sum: builtin___int = ...
    bucket_counts: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...
    explicit_bounds: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___float] = ...

    @property
    def labels(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]: ...

    @property
    def exemplars(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___IntExemplar]: ...

    def __init__(self,
        *,
        labels : typing___Optional[typing___Iterable[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]] = None,
        start_time_unix_nano : typing___Optional[builtin___int] = None,
        time_unix_nano : typing___Optional[builtin___int] = None,
        count : typing___Optional[builtin___int] = None,
        sum : typing___Optional[builtin___int] = None,
        bucket_counts : typing___Optional[typing___Iterable[builtin___int]] = None,
        explicit_bounds : typing___Optional[typing___Iterable[builtin___float]] = None,
        exemplars : typing___Optional[typing___Iterable[type___IntExemplar]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> IntHistogramDataPoint: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> IntHistogramDataPoint: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"bucket_counts",b"bucket_counts",u"count",b"count",u"exemplars",b"exemplars",u"explicit_bounds",b"explicit_bounds",u"labels",b"labels",u"start_time_unix_nano",b"start_time_unix_nano",u"sum",b"sum",u"time_unix_nano",b"time_unix_nano"]) -> None: ...
type___IntHistogramDataPoint = IntHistogramDataPoint

class DoubleHistogramDataPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    start_time_unix_nano: builtin___int = ...
    time_unix_nano: builtin___int = ...
    count: builtin___int = ...
    sum: builtin___float = ...
    bucket_counts: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...
    explicit_bounds: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___float] = ...

    @property
    def labels(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]: ...

    @property
    def exemplars(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___DoubleExemplar]: ...

    def __init__(self,
        *,
        labels : typing___Optional[typing___Iterable[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]] = None,
        start_time_unix_nano : typing___Optional[builtin___int] = None,
        time_unix_nano : typing___Optional[builtin___int] = None,
        count : typing___Optional[builtin___int] = None,
        sum : typing___Optional[builtin___float] = None,
        bucket_counts : typing___Optional[typing___Iterable[builtin___int]] = None,
        explicit_bounds : typing___Optional[typing___Iterable[builtin___float]] = None,
        exemplars : typing___Optional[typing___Iterable[type___DoubleExemplar]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> DoubleHistogramDataPoint: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> DoubleHistogramDataPoint: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"bucket_counts",b"bucket_counts",u"count",b"count",u"exemplars",b"exemplars",u"explicit_bounds",b"explicit_bounds",u"labels",b"labels",u"start_time_unix_nano",b"start_time_unix_nano",u"sum",b"sum",u"time_unix_nano",b"time_unix_nano"]) -> None: ...
type___DoubleHistogramDataPoint = DoubleHistogramDataPoint

class IntExemplar(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    time_unix_nano: builtin___int = ...
    value: builtin___int = ...
    span_id: builtin___bytes = ...
    trace_id: builtin___bytes = ...

    @property
    def filtered_labels(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]: ...

    def __init__(self,
        *,
        filtered_labels : typing___Optional[typing___Iterable[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]] = None,
        time_unix_nano : typing___Optional[builtin___int] = None,
        value : typing___Optional[builtin___int] = None,
        span_id : typing___Optional[builtin___bytes] = None,
        trace_id : typing___Optional[builtin___bytes] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> IntExemplar: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> IntExemplar: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"filtered_labels",b"filtered_labels",u"span_id",b"span_id",u"time_unix_nano",b"time_unix_nano",u"trace_id",b"trace_id",u"value",b"value"]) -> None: ...
type___IntExemplar = IntExemplar

class DoubleExemplar(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    time_unix_nano: builtin___int = ...
    value: builtin___float = ...
    span_id: builtin___bytes = ...
    trace_id: builtin___bytes = ...

    @property
    def filtered_labels(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]: ...

    def __init__(self,
        *,
        filtered_labels : typing___Optional[typing___Iterable[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]] = None,
        time_unix_nano : typing___Optional[builtin___int] = None,
        value : typing___Optional[builtin___float] = None,
        span_id : typing___Optional[builtin___bytes] = None,
        trace_id : typing___Optional[builtin___bytes] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> DoubleExemplar: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> DoubleExemplar: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"filtered_labels",b"filtered_labels",u"span_id",b"span_id",u"time_unix_nano",b"time_unix_nano",u"trace_id",b"trace_id",u"value",b"value"]) -> None: ...
type___DoubleExemplar = DoubleExemplar
